@@ -1,7 +1,7 @@
 /*
  * Fritz!Box plugin for VDR
  *
- * Copyright (C) 2007 Joachim Wilke <vdr@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <vdr@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@
 #include "notifyosd.h"
 #include "menu.h"
 
-static const char *VERSION        = "1.4.3";
+static const char *VERSION        = "1.5.2";
 static const char *DESCRIPTION    = trNOOP("Fritz Plugin for AVM Fritz!Box");
 static const char *MAINMENUENTRY  = trNOOP("Fritz!Box");
 
@@ -43,6 +43,7 @@ cPluginFritzbox::cPluginFritzbox(void)
 	// VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
 	event = NULL;
 	logPersonalInfo = false;
+	migratePassword = false;
 }
 
 cPluginFritzbox::~cPluginFritzbox()
@@ -107,9 +108,9 @@ bool cPluginFritzbox::Initialize(void)
 bool cPluginFritzbox::Start(void)
 {
 	// first enable logging to syslog
-	dlog = new cLogStream(cLogBuf::DEBUG);
-	elog = new cLogStream(cLogBuf::ERROR);
-	ilog = new cLogStream(cLogBuf::INFO);
+	dlog = new cLogStream(LogBuf::DEBUG);
+	elog = new cLogStream(LogBuf::ERROR);
+	ilog = new cLogStream(LogBuf::INFO);
 	// use logging objects with libfritz++
 	fritz::Config::SetupLogging(dlog, ilog, elog);
 
@@ -126,6 +127,11 @@ void cPluginFritzbox::Stop(void)
 	SetupStore("ActiveFonbook",       fritzboxConfig.activeFonbookID.c_str());
 	SetupStore("CountryCode",         fritzboxConfig.countryCode.c_str());
 	SetupStore("RegionCode",          fritzboxConfig.regionCode.c_str());
+	// Migrate old setup parameters
+	if (migratePassword) {
+		SetupStore("EncodedPassword", fritzboxConfig.string2hex(fritzboxConfig.password).c_str());
+		SetupStore("Password",        "");
+	}
 	// Stop any background activities the plugin shall perform.
 	fritz::Config::Shutdown();
 	if (event)
@@ -207,6 +213,15 @@ cMenuSetupPage *cPluginFritzbox::SetupMenu(void)
 bool cPluginFritzbox::SetupParse(const char *Name, const char *Value)
 {
 	// Parse your own setup parameters and store their values.
+	if (!strcasecmp(Name, "Password")) {
+		if (fritzboxConfig.password.size() > 0) {
+			migratePassword = true;
+			return true;
+		}
+		if (strlen(Value) > 0) {
+			migratePassword = true;
+		}
+	}
 	return fritzboxConfig.SetupParse(Name, Value);
 }
 
@@ -243,17 +258,23 @@ void cPluginFritzbox::Action() {
 		fritz::Listener::CreateListener(event);
 }
 
-std::string cPluginFritzbox::FonbookEntryTypeToName(const fritz::FonbookEntry::eType type) {
+std::string cPluginFritzbox::FonbookEntryTypeToName(const fritz::FonbookEntry::eType type, bool longName) {
 	switch (type) {
 	case fritz::FonbookEntry::TYPE_HOME:
-		//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "home"
-		return tr("H");
+		return longName ?
+				tr("Private") :
+				//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "home"
+				tr("H");
 	case fritz::FonbookEntry::TYPE_MOBILE:
-		//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "mobile"
-		return tr("M");
+		return longName ?
+				tr("Mobile") :
+				//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "mobile"
+				tr("M");
 	case fritz::FonbookEntry::TYPE_WORK:
-		//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "work"
-		return tr("W");
+		return longName ?
+				tr("Business") :
+				//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "work"
+				tr("W");
 	default:
 		return "";
 	}
