@@ -1,7 +1,7 @@
 /*
  * Fritz!Box plugin for VDR
  *
- * Copyright (C) 2007 Joachim Wilke <vdr@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <vdr@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,7 +37,7 @@ private:
 	std::string mainMenuEntry;
 	bool logPersonalInfo;
 	std::string onCallCmd;
-
+	bool migratePassword;
 public:
 	cPluginFritzbox(void);
 	virtual ~cPluginFritzbox();
@@ -62,7 +62,7 @@ public:
 	// from cThread:
 	virtual void Action();
 	// various things
-	static std::string FonbookEntryTypeToName(const fritz::FonbookEntry::eType type);
+	static std::string FonbookEntryTypeToName(const fritz::FonbookEntry::eType type, bool longName = false);
 
 };
 
