@@ -1,7 +1,7 @@
 /*
  * Fritz!Box plugin for VDR
  *
- * Copyright (C) 2007 Joachim Wilke <vdr@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <vdr@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
 #include <vdr/remote.h>
 #include <vdr/player.h>
 #include <vdr/skins.h>
+#include <vdr/shutdown.h>
 #include <vdr/thread.h>
 
 #include <Fonbook.h>
@@ -31,6 +32,7 @@
 
 cFritzEventHandler::cFritzEventHandler(std::string onCallCmd) {
 	muted = false;
+	volumeLevel = 0;
 	paused = false;
 	getCallInfoCalled = false;
 	this->onCallCmd = onCallCmd;
@@ -58,7 +60,8 @@ std::vector<int> cFritzEventHandler::GetPendingCallIds() {
 	std::vector<int> ids;
 	mutex.Lock();
 	for (std::map<int, sConnection>::iterator it = connections.begin(); it != connections.end(); it++) {
-		if (static_cast<sConnection>((*it).second).callInfo) {
+		if ((static_cast<sConnection>((*it).second).displayed == false) ||
+			(static_cast<sConnection>((*it).second).state == sConnection::RINGING )) {
 			ids.push_back((*it).first);
 		}
 	}
@@ -70,11 +73,10 @@ void cFritzEventHandler::NotificationDone(int connId) {
 	mutex.Lock();
 	sConnection &connection = connections[connId];
 	connection.displayed = true;
-	if (connection.state != sConnection::RINGING) {
+	if (connection.state == sConnection::IDLE) {
 		delete connection.callInfo;
 		connection.callInfo = NULL;
-		if (connection.state == sConnection::IDLE)
-			connections.erase(connId);
+		connections.erase(connId);
 	}
 	mutex.Unlock();
 }
@@ -121,19 +123,25 @@ std::string cFritzEventHandler::ComposeCallMessage(int connId) {
 	return rMsg;
 }
 
+bool cFritzEventHandler::CareForCall(bool outgoing) {
+	if (fritzboxConfig.reactOnDirection != fritzboxConfig.DIRECTION_ANY) {
+		if (outgoing && fritzboxConfig.reactOnDirection
+				!= fritzboxConfig.DIRECTION_OUT)
+			return false;
+		if (!outgoing && fritzboxConfig.reactOnDirection
+				!= fritzboxConfig.DIRECTION_IN)
+			return false;
+	}
+	return true;
+}
+
 void cFritzEventHandler::HandleCall(bool outgoing, int connId,
 		std::string remoteNumber, std::string remoteName,
 		fritz::FonbookEntry::eType remoteType, std::string localParty,
 		std::string medium, std::string mediumName) {
 
-	if (fritzboxConfig.reactOnDirection != fritzboxConfig.DIRECTION_ANY) {
-		if (outgoing && fritzboxConfig.reactOnDirection
-				!= fritzboxConfig.DIRECTION_OUT)
-			return;
-		if (!outgoing && fritzboxConfig.reactOnDirection
-				!= fritzboxConfig.DIRECTION_IN)
-			return;
-	}
+	if (!CareForCall(outgoing))
+		return;
 
 	bool currPlay, currForw;
 	int currSpeed;
@@ -142,16 +150,19 @@ void cFritzEventHandler::HandleCall(bool outgoing, int connId,
 		control->GetReplayMode(currPlay, currForw, currSpeed);
 	}
 
-	if (fritzboxConfig.muteOnCall && !cDevice::PrimaryDevice()->IsMute()) {
+	// check for muting
+	if (fritzboxConfig.muteOnCall && !fritzboxConfig.muteAfterConnect && !cDevice::PrimaryDevice()->IsMute()) {
 		INF((outgoing ? "outgoing": "incoming") << " call, muting.");
-		cDevice::PrimaryDevice()->ToggleMute();
-		muted = true;
+		DoMute();
 	}
-	if (fritzboxConfig.pauseOnCall && !paused && control && currPlay) {
+	// check for pausing replay or live tv
+	if (fritzboxConfig.pauseOnCall && !paused &&
+	    ((control && currPlay) || (fritzboxConfig.pauseLive && !ShutdownHandler.IsUserInactive()))) {
 		INF((outgoing ? "outgoing": "incoming") << " call, pressing kPause.");
 		cRemote::Put(kPause);
 		paused = true;
 	}
+
 	if (medium.compare(mediumName) == 0) {
 		if (mediumName.find("SIP") != std::string::npos)
 			mediumName.replace(0, 3, "VoIP ");
@@ -194,27 +205,42 @@ void cFritzEventHandler::HandleCall(bool outgoing, int connId,
 		}
 	}
 
-	Exec(std::stringstream().flush() << onCallCmd << " CALL "
-			                         << (outgoing ? "OUT " : "IN ")
-			                         << connId << " "
-			                         << remoteNumber << " \"" << remoteName << "\" "
-			                         << localParty << " "
-			                         << medium << " \"" << mediumName << "\"");
+	if (onCallCmd.size())
+		Exec(std::stringstream().flush() << onCallCmd << " CALL "
+									     << (outgoing ? "OUT " : "IN ")
+			                             << connId << " "
+			                             << remoteNumber << " \"" << remoteName << "\" "
+			                             << localParty << " "
+			                             << medium << " \"" << mediumName << "\"");
 }
 
 void cFritzEventHandler::HandleConnect(int connId) {
+	if (connections.find(connId) == connections.end())
+		return;
+	bool outgoing = connections[connId].callInfo->isOutgoing;
+	if (!CareForCall(outgoing))
+		return;
+
+	if (fritzboxConfig.muteOnCall && fritzboxConfig.muteAfterConnect && !cDevice::PrimaryDevice()->IsMute()) {
+		INF("muting connected call");
+		DoMute();
+	}
+
 	mutex.Lock();
 	sConnection &connection = connections[connId];
 	connection.state = sConnection::ACTIVE;
-	if (connection.displayed) {
-		delete connection.callInfo;
-		connection.callInfo = NULL;
-	}
 	mutex.Unlock();
-	Exec(std::stringstream().flush() << onCallCmd << " CONNECT " << connId);
+	if (onCallCmd.size())
+		Exec(std::stringstream().flush() << onCallCmd << " CONNECT " << connId);
 }
 
 void cFritzEventHandler::HandleDisconnect(int connId, std::string duration) {
+	if (connections.find(connId) == connections.end())
+		return;
+	bool outgoing = connections[connId].callInfo->isOutgoing;
+	if (!CareForCall(outgoing))
+		return;
+
 	bool currPlay, currForw;
 	int currSpeed;
 	cControl *control = cControl::Control();
@@ -241,10 +267,9 @@ void cFritzEventHandler::HandleDisconnect(int connId, std::string duration) {
 	}
 	mutex.Unlock();
 	// unmute, if applicable
-	if (!activeCallsPending && muted && cDevice::PrimaryDevice()->IsMute()) {
+	if (!activeCallsPending && muted) {
 		INF("Finished all calls, unmuting.");
-		cDevice::PrimaryDevice()->ToggleMute();
-		muted = false;
+		DoUnmute();
 	}
 	// resume, if applicable
 	if (!activeCallsPending && paused) {
@@ -256,12 +281,32 @@ void cFritzEventHandler::HandleDisconnect(int connId, std::string duration) {
 		paused = false;
 	}
 
-	Exec(std::stringstream().flush() << onCallCmd << " DISCONNECT " << connId << " " << duration);
-	if (!activeCallsPending)
-		Exec(std::stringstream().flush() << onCallCmd << " FINISHED");
+	if (onCallCmd.size()) {
+		Exec(std::stringstream().flush() << onCallCmd << " DISCONNECT "
+				<< connId << " " << duration);
+		if (!activeCallsPending)
+			Exec(std::stringstream().flush() << onCallCmd << " FINISHED");
+	}
 }
 
 void cFritzEventHandler::Exec(const std::ostream & cmd) const {
 	const std::stringstream &sCmd = static_cast<const std::stringstream&>(cmd);
 	SystemExec(sCmd.str().c_str(), false);
 }
+
+void cFritzEventHandler::DoMute() {
+	if (fritzboxConfig.muteVolumeLevel < 100) {
+		volumeLevel = cDevice::PrimaryDevice()->CurrentVolume();
+		cDevice::PrimaryDevice()->SetVolume(volumeLevel * (100 - fritzboxConfig.muteVolumeLevel) / 100, true);
+	} else if (!cDevice::PrimaryDevice()->IsMute())
+		cDevice::PrimaryDevice()->ToggleMute();
+	muted = true;
+}
+
+void cFritzEventHandler::DoUnmute() {
+	if (fritzboxConfig.muteVolumeLevel < 100) {
+		cDevice::PrimaryDevice()->SetVolume(volumeLevel, true);
+	} else if (cDevice::PrimaryDevice()->IsMute())
+		cDevice::PrimaryDevice()->ToggleMute();
+	muted = false;
+}
