@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,9 +19,8 @@
  *
  */
 
-
-#ifndef CALLLIST_H_
-#define CALLLIST_H_
+#ifndef CALLLIST_H
+#define CALLLIST_H
 
 #include <string>
 #include <vector>
@@ -58,6 +57,7 @@ public:
 	std::string duration;
 	time_t      timestamp;
 	bool MatchesFilter();
+	bool MatchesRemoteNumber(std::string number);
 };
 
 class CallList : public ost::Thread
