@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,11 +19,11 @@
  *
  */
 
-
-#ifndef FRITZFONBUCH_H_
-#define FRITZFONBUCH_H_
+#ifndef FRITZFONBOOK_H
+#define FRITZFONBOOK_H
 
 #include <cc++/thread.h>
+
 #include "XmlFonbook.h"
 
 namespace fritz{
