@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,9 +19,8 @@
  *
  */
 
-
-#ifndef HTTPCLIENT_H_
-#define HTTPCLIENT_H_
+#ifndef HTTPCLIENT_H
+#define HTTPCLIENT_H
 
 #include "cc++/url.h"
 #include "TcpClient.h"
@@ -33,11 +32,10 @@ private:
 	ost2::URLStream *urlStream;
 protected:
 	HttpClient(std::string &host, int port, ost2::URLStream *stream);
-	ost2::URLStream::Error returnCode;
 	std::string Result();
     std::string BuildUrl(const std::ostream & url);
 public:
-	HttpClient(std::string &host, int port = 80);
+	explicit HttpClient(std::string &host, int port = 80);
 	virtual ~HttpClient();
 	std::string Get(const std::ostream& os);
 	std::string Post(const std::ostream &url, const std::ostream &postdata);
