@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,12 +19,9 @@
  *
  */
 
+#ifndef FRITZLISTENER_H
+#define FRITZLISTENER_H
 
-#ifndef FRITZLISTENER_H_
-#define FRITZLISTENER_H_
-
-#include <string>
-#include <vector>
 #include <cc++/thread.h>
 
 #include "Fonbook.h"
@@ -68,7 +65,7 @@ public:
 	 * Fritz!Box. The application has to provide an EventHandler object, which has to inherit
 	 * fritz::EventHandler. The listener notifies the application about call events using this object.
 	 * @param A pointer to the eventHandler. Subsequent calls to CreateListener, e.g., in case of
-	 * configuration changes, can ommit this parameter. Then, the existing EventHandler is used.
+	 * configuration changes, can omit this parameter. Then, the existing EventHandler is used.
 	 */
 	static void CreateListener(EventHandler *event = NULL);
 	static void DeleteListener();
