@@ -19,17 +19,18 @@
  *
  */
 
-#include <string.h>
-#include <stdlib.h>
+#include "Tools.h"
+
+#include <string>
+#include <cstdlib>
 #include <locale.h>
 #include <langinfo.h>
 #include <sstream>
 #include <iostream>
 #include <errno.h>
-#include "FritzClient.h"
-#include "Tools.h"
-#include "Config.h"
 
+#include "Config.h"
+#include "FritzClient.h"
 
 namespace fritz{
 
@@ -186,7 +187,9 @@ bool Tools::MatchesMsnFilter(const std::string &number){
 		return true;
 	// if number does contain a MSN out of the MSN filter, true is returned
 	for (size_t pos=0; pos < gConfig->getMsnFilter().size(); pos++) {
-		if (number.find(gConfig->getMsnFilter()[pos]) != std::string::npos ) {
+		std::string msn = gConfig->getMsnFilter()[pos];
+		size_t index = number.find(msn);
+		if ( index != std::string::npos && index + msn.length() == number.length()) {
 			//matched
 			return true;
 		}
@@ -233,24 +236,30 @@ int Tools::CompareNormalized(std::string number1, std::string number2) {
 
 bool Tools::GetLocationSettings() {
 	//	get settings from Fritz!Box.
-	FritzClient fc;
-	std::string msg = fc.RequestLocationSettings();
+	FritzClient *fc = gConfig->fritzClientFactory->create();
+	std::string msg = fc->RequestLocationSettings();
 
 	size_t lkzStart = msg.find("telcfg:settings/Location/LKZ");
 	if (lkzStart == std::string::npos) {
 		ERR("Parser error in GetLocationSettings(). Could not find LKZ.");
 		ERR("LKZ/OKZ not set! Resolving phone numbers may not always work.");
-		return fc.hasValidPassword();
+		bool returnValue = fc->hasValidPassword();
+		delete fc;
+		return returnValue;
 	}
-	lkzStart += 37;
+	lkzStart += 30;
+	lkzStart        = msg.find("\"", lkzStart) +1;
 	size_t lkzStop  = msg.find("\"", lkzStart);
 	size_t okzStart = msg.find("telcfg:settings/Location/OKZ");
 	if (okzStart == std::string::npos) {
 		ERR("Parser error in GetLocationSettings(). Could not find OKZ.");
 		ERR("OKZ not set! Resolving phone numbers may not always work.");
-		return fc.hasValidPassword();
+		bool returnValue = fc->hasValidPassword();
+		delete fc;
+		return returnValue;
 	}
-	okzStart += 37;
+	okzStart += 30;
+	okzStart       = msg.find("\"", okzStart) +1;
 	size_t okzStop = msg.find("\"", okzStart);
 	gConfig->setCountryCode( msg.substr(lkzStart, lkzStop - lkzStart) );
 	gConfig->setRegionCode( msg.substr(okzStart, okzStop - okzStart) );
@@ -264,7 +273,9 @@ bool Tools::GetLocationSettings() {
 	} else {
 		ERR("OKZ not set! Resolving phone numbers may not always work.");
 	}
-	return fc.hasValidPassword();
+	bool returnValue = fc->hasValidPassword();
+	delete fc;
+	return returnValue;
 }
 
 void Tools::GetSipSettings() {
@@ -272,11 +283,42 @@ void Tools::GetSipSettings() {
 	if ( gConfig->getSipNames().size() > 0 )
 		return;
 	// ...otherwise get settings from Fritz!Box.
-	FritzClient fc;
-	std::string msg = fc.RequestSipSettings();
+	FritzClient *fc = gConfig->fritzClientFactory->create();
+	std::string msg = fc->RequestSipSettings();
+	delete fc;
 
 	std::vector<std::string> sipNames;
+	std::vector<std::string> sipMsns;
 
+	// new parser for lua page
+	if (msg.find("<!-- pagename:/fon_num/fon_num_list.lua-->") != std::string::npos) {
+		std::string name, msn;
+
+		for (size_t i = 0; i < 10; i++) {
+			std::stringstream msnTag, nameTag;
+			msnTag << "telcfg:settings/SIP" << i << "/MSN";
+			nameTag << "telcfg:settings/SIP" << i << "/Name";
+			size_t msnPos = msg.find(msnTag.str());
+			size_t namePos = msg.find(nameTag.str());
+			if (msnPos == std::string::npos) {
+				sipNames.push_back("");
+				sipMsns.push_back("");
+				continue;
+			}
+			msnPos = msg.find("\"", msnPos + msnTag.str().length() + 1);
+			namePos = msg.find("\"", namePos + nameTag.str().length() + 1);
+			msn = msg.substr(msnPos + 1, msg.find("\"", msnPos + 1) - msnPos -1);
+			name = msg.substr(namePos + 1, msg.find("\"", namePos + 1) - namePos -1);
+			sipNames.push_back(name);
+			sipMsns.push_back(msn);
+			DBG("Found SIP" << i << " provider name " << name << " / MSN " << (gConfig->logPersonalInfo() ? msn : HIDDEN));
+		}
+		gConfig->setSipNames(sipNames);
+		gConfig->setSipMsns(sipMsns);
+		return;
+	}
+
+	// old parser
 	// check if the structure of the HTML page matches our search pattern
 	if (msg.find("function AuswahlDisplay") == std::string::npos){
 		ERR("Parser error in GetSipSettings(). Could not find SIP list.");
@@ -291,6 +333,17 @@ void Tools::GetSipSettings() {
 			// end of list reached
 			break;
 		}
+		size_t msnStart = msg.rfind("<td class=\"c2\">", sipStart);
+		if (msnStart == std::string::npos) {
+			// something is wrong with the structure of the HTML page
+			ERR("Parser error in GetSipSettings(). Could not find SIP provider name.");
+			ERR("SIP provider names not set! Usage of SIP provider names not possible.");
+			return;
+		}
+		msnStart += 15;
+		size_t msnStop = msg.find("</td>", msnStart);
+		std::string msn = msg.substr(msnStart, msnStop - msnStart);
+
 		size_t hostStart = msg.rfind("ProviderDisplay(\"",sipStart);
 		if (hostStart == std::string::npos) {
 			// something is wrong with the structure of the HTML page
@@ -339,10 +392,11 @@ void Tools::GetSipSettings() {
 		}
 
 		sipNames.push_back(sipName);
-		DBG("Found SIP" << i << " (" << hostName << ") provider name " << sipName);
+		sipMsns.push_back(msn);
+		DBG("Found SIP" << i << " (" << hostName << ") provider name " << sipName << " / MSN " << (gConfig->logPersonalInfo() ? msn : HIDDEN));
 	}
 	gConfig->setSipNames(sipNames);
-
+	gConfig->setSipMsns(sipMsns);
 }
 
 std::string Tools::Tokenize(const std::string &buffer, const char delimiter, size_t pos) {
