@@ -19,24 +19,23 @@
  *
  */
 
-#ifndef XMLFONBOOK_H_
-#define XMLFONBOOK_H_
+#ifndef XMLFONBOOK_H
+#define XMLFONBOOK_H
 
 #include "Fonbook.h"
 
 namespace fritz {
 
-class XmlFonbook: public fritz::Fonbook {
+class XmlFonbook: public Fonbook {
 private:
 	std::string ExtractXmlAttributeValue(std::string element, std::string attribute, std::string xml);
 	std::string ExtractXmlElementValue(std::string element, std::string xml);
 	std::string charset;
 protected:
-	std::string convertEntities(std::string s);
 	void ParseXmlFonbook(std::string *msg);
 	std::string SerializeToXml();
 public:
-	XmlFonbook();
+	XmlFonbook(std::string title, std::string techId, bool writeable);
 	virtual ~XmlFonbook();
 };
 
