@@ -1,7 +1,7 @@
 /*
  * Fritz!Box plugin for VDR
  *
- * Copyright (C) 2007 Joachim Wilke <vdr@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <vdr@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -114,9 +114,15 @@ void cMenuSetupFritzbox::Setup(void) {
 	Add(new cMenuEditStrItem (tr("Region code"),                            regionCode,             10,          "0123456789"));
 	Add(new cMenuEditStraItem(tr("React on calls"),                         &reactOnDirection,      3,           directions  ));
 	Add(new cMenuEditBoolItem(tr("Mute on call"),                   		&muteOnCall,   			trVDR("no"), trVDR("yes")));
+	if (muteOnCall) {
+		Add(new cMenuEditBoolItem(tr("Mute only after connect"),            &muteAfterConnect,      trVDR("no"), trVDR("yes")));
+		Add(new cMenuEditIntItem(tr("Decrease volume by [1..100%]"),        &muteVolumeLevel,       1,           100));
+	}
 	Add(new cMenuEditBoolItem(tr("Pause on call"),   	             		&pauseOnCall,  			trVDR("no"), trVDR("yes")));
-	if (pauseOnCall)
+	if (pauseOnCall) {
+		Add(new cMenuEditBoolItem(tr("Pause live tv"),                      &pauseLive,             trVDR("no"), trVDR("yes")));
 		Add(new cMenuEditBoolItem(tr("Resume after call"),            		&resumeAfterCall,		trVDR("no"), trVDR("yes")));
+	}
 	Add(new cMenuEditBoolItem(tr("Show calls"),            		            &showNumber,   			trVDR("no"), trVDR("yes")));
 	Add(new cMenuEditBoolItem(tr("Show detailed call information"),         &useNotifyOsd,          trVDR("no"), trVDR("yes")));
 	Add(new cMenuEditBoolItem(tr("Detailed call lists"),                    &showNumberInCallList, 	trVDR("no"), trVDR("yes")));
@@ -126,7 +132,7 @@ void cMenuSetupFritzbox::Setup(void) {
 	Add(new cOsdItem         (tr("Setup phonebooks to use..."),             osUser1                                          ));
 	Add(new cMenuEditBoolItem(tr("Restrict monitor to certain extensions"), &msnFilter,    			trVDR("no"), trVDR("yes")));
 	if (msnFilter) {
-		Add(new cMenuEditIntItem (tr("Number of monitored extensions"), &msnCount, 1, MAX_MSN_COUNT));
+		Add(new cMenuEditIntItem (tr("Number of monitored extensions"), &msnCount, 0, MAX_MSN_COUNT));
 		for (int p = 0; p < msnCount; p++)
 			Add(new cMenuEditStrItem(tr("Extension"), msn[p], MaxFileName, "1234567890"));
 	}
@@ -175,6 +181,10 @@ eOSState cMenuSetupFritzbox::ProcessKey(eKeys Key) {
 			Setup();
 			pauseOnCallBefore = pauseOnCall;
 		}
+		if (muteOnCall != muteOnCallBefore) {
+			Setup();
+			muteOnCallBefore = muteOnCall;
+		}
 	}
 
 	if (state == osUnknown) {
@@ -212,7 +222,10 @@ void cMenuSetupFritzbox::Store(void) {
 	//
 	fritzboxConfig.reactOnDirection     = reactOnDirection;
 	fritzboxConfig.muteOnCall     		= muteOnCall;
+	fritzboxConfig.muteAfterConnect     = muteAfterConnect;
+	fritzboxConfig.muteVolumeLevel      = muteVolumeLevel;
 	fritzboxConfig.pauseOnCall     		= pauseOnCall;
+	fritzboxConfig.pauseLive            = pauseLive;
 	fritzboxConfig.resumeAfterCall 		= resumeAfterCall;
 	fritzboxConfig.showNumber     		= showNumber;
 	fritzboxConfig.useNotifyOsd         = useNotifyOsd;
@@ -237,10 +250,14 @@ void cMenuSetupFritzbox::Store(void) {
 	((cThread *)fritzbox)->Start(); // re-read configuration, notify libfritz++ about changes
 
 	SetupStore("Url",          			url);
-	SetupStore("Password",     			fritzboxConfig.password.c_str());
+	SetupStore("Password",     			""); // has been migrated to EncodedPassword
+	SetupStore("EncodedPassword",       fritzboxConfig.string2hex(fritzboxConfig.password).c_str());
 	SetupStore("ReactOnDirection",      reactOnDirection);
 	SetupStore("MuteOnCall",   			muteOnCall);
+	SetupStore("MuteAfterConnect",      muteAfterConnect);
+	SetupStore("MuteVolumeLevel",       muteVolumeLevel);
 	SetupStore("PauseOnCall",  			pauseOnCall);
+	SetupStore("PauseLive",             pauseLive);
 	SetupStore("ResumeAfterCall",       resumeAfterCall);
 	SetupStore("ShowNumber",   			showNumber);
 	SetupStore("UseNotifyOsd",          useNotifyOsd);
@@ -268,8 +285,12 @@ cMenuSetupFritzbox::cMenuSetupFritzbox(cPluginFritzbox *fritzbox)
 	}
 	reactOnDirection     = fritzboxConfig.reactOnDirection;
 	muteOnCall      	 = fritzboxConfig.muteOnCall;
+	muteOnCallBefore     = muteOnCall;
+	muteAfterConnect     = fritzboxConfig.muteAfterConnect;
+	muteVolumeLevel      = fritzboxConfig.muteVolumeLevel;
 	pauseOnCall      	 = fritzboxConfig.pauseOnCall;
 	pauseOnCallBefore    = pauseOnCall;
+	pauseLive            = fritzboxConfig.pauseLive;
 	resumeAfterCall      = fritzboxConfig.resumeAfterCall;
 	showNumber      	 = fritzboxConfig.showNumber;
 	useNotifyOsd         = fritzboxConfig.useNotifyOsd;
@@ -415,7 +436,10 @@ sFritzboxConfig::sFritzboxConfig() {
 	regionCode              = "";
 	reactOnDirection        = DIRECTION_IN;
 	muteOnCall      		= 0;
+	muteAfterConnect        = 0;
+	muteVolumeLevel         = 100;
 	pauseOnCall      		= 0;
+	pauseLive               = 0;
 	resumeAfterCall         = 1;
 	showNumber      		= 1;
 	useNotifyOsd            = 0;
@@ -469,10 +493,14 @@ bool sFritzboxConfig::SetupParseFonbooks(const char *value){
 
 bool sFritzboxConfig::SetupParse(const char *name, const char *value) {
 	if      (!strcasecmp(name, "Url"))          		url          		 = value;
-	else if (!strcasecmp(name, "Password"))     		password     		 = value;
+	else if (!strcasecmp(name, "Password"))	            password             = value;
+	else if (!strcasecmp(name, "EncodedPassword"))      password             = hex2string(value);
 	else if (!strcasecmp(name, "ReactOnDirection"))     reactOnDirection     = atoi(value);
 	else if (!strcasecmp(name, "MuteOnCall"))   		muteOnCall   		 = atoi(value);
+	else if (!strcasecmp(name, "MuteAfterConnect"))     muteAfterConnect   	 = atoi(value);
+	else if (!strcasecmp(name, "MuteVolumeLevel"))      muteVolumeLevel   	 = atoi(value);
 	else if (!strcasecmp(name, "PauseOnCall"))   		pauseOnCall   		 = atoi(value);
+	else if (!strcasecmp(name, "PauseLive"))            pauseLive            = atoi(value);
 	else if (!strcasecmp(name, "ResumeAfterCall"))      resumeAfterCall      = atoi(value);
 	else if (!strcasecmp(name, "ShowNumber"))   		showNumber   		 = atoi(value);
 	else if (!strcasecmp(name, "UseNotifyOsd"))         useNotifyOsd         = atoi(value);
@@ -489,3 +517,22 @@ bool sFritzboxConfig::SetupParse(const char *name, const char *value) {
 	else return false;
 	return true;
 }
+
+std::string sFritzboxConfig::string2hex(std::string input) {
+	std::stringstream output;
+	for (std::string::iterator it = input.begin(); it < input.end(); it++)
+		output << std::hex << static_cast<int>(*it);
+	return output.str();
+}
+
+std::string sFritzboxConfig::hex2string(std::string input) {
+	std::stringstream output;
+	for (std::string::iterator it = input.begin(); it < input.end(); it += 2) {
+		std::stringstream buffer;
+		int value;
+		buffer << it[0] << it[1] ;
+		buffer >> std::hex >> value;
+		output << static_cast<char>(value);
+	}
+	return output.str();
+}
