@@ -1,7 +1,7 @@
 /*
  * Fritz!Box plugin for VDR
  *
- * Copyright (C) 2007 Joachim Wilke <vdr@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <vdr@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,8 +50,12 @@ private:
 	char *menus[4];
 	int reactOnDirection;
 	int muteOnCall;
+	int muteOnCallBefore;
+	int muteAfterConnect;
+	int muteVolumeLevel;
 	int pauseOnCall;
 	int pauseOnCallBefore;
+	int pauseLive;
 	int resumeAfterCall;
 	int showNumber;
 	int useNotifyOsd;
@@ -105,6 +109,8 @@ public:
 	bool SetupParseMsn(const char *value);
 	bool SetupParseFonbooks(const char *value);
 	bool SetupParse(const char *Name, const char *Value);
+	std::string string2hex(std::string input);
+	std::string hex2string(std::string input);
 	std::string configDir;              // path to plugins' config files (e.g., local phone book)
 	std::string pluginName;             // name of this plugin (e.g., for cRemote::CallPlugin)
 	std::string lang;                   // webinterface language
@@ -115,7 +121,10 @@ public:
 	std::string regionCode;             // fritz!box region-code
 	int reactOnDirection;               // what type of calls are we interested in (eDirection)?
 	int muteOnCall;                     // mute audio on calls
+	int muteAfterConnect;               // mute only after call connects
+	int muteVolumeLevel;                // on mute, decrease volume by muteVolumeLevel %
 	int pauseOnCall;                    // pause playback on calls
+	int pauseLive;                      // pause livetv on calls, too
 	int resumeAfterCall;                // resume playback after all calls have finished
 	int showNumber;                     // show notification on osd on calls
 	int useNotifyOsd;                   // use the extended notification osd and not Skins.Message
